==> haskell-pipes-4.1.8-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-pipes/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes
version: 4.1.8
id: pipes-4.1.8-48aeb04c3fec70e47e537a12d228def1
key: pipes_77ihSQ5c6PS0Tlq86aN8G4
license: BSD3
copyright: 2012-2014 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components
    .
    Advantages over traditional streaming libraries:
    .
    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''
    .
    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion
    .
    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies
    .
    * /Elegant semantics/: Use practical category theory
    .
    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes
    .
    * /Bidirectionality/: Implement duplex channels
    .
    * /Extensive Documentation/: Second to none!
    .
    Import "Pipes" to use the library.
    .
    Read "Pipes.Tutorial" for an extensive tutorial.
category: Control, Pipes
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/pipes-4.1.8
library-dirs: /usr/lib/ghc-7.10.3/site-local/pipes-4.1.8
data-dir: /usr/share/arm-linux-ghc-7.10.3/pipes-4.1.8
hs-libraries: HSpipes-4.1.8-77ihSQ5c6PS0Tlq86aN8G4
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html: /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-4.1.9-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-pipes/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes
version: 4.1.9
id: pipes-4.1.9-8b262b53761b077dec55bfc46d38ba0f
key: pipes_BuPv5OpHkYKJdGg885pSs7
license: BSD3
copyright: 2012-2014 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components
    .
    Advantages over traditional streaming libraries:
    .
    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''
    .
    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion
    .
    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies
    .
    * /Elegant semantics/: Use practical category theory
    .
    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes
    .
    * /Bidirectionality/: Implement duplex channels
    .
    * /Extensive Documentation/: Second to none!
    .
    Import "Pipes" to use the library.
    .
    Read "Pipes.Tutorial" for an extensive tutorial.
category: Control, Pipes
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/pipes-4.1.9
library-dirs: /usr/lib/ghc-7.10.3/site-local/pipes-4.1.9
data-dir: /usr/share/arm-linux-ghc-7.10.3/pipes-4.1.9
hs-libraries: HSpipes-4.1.9-BuPv5OpHkYKJdGg885pSs7
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html: /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
